"use strict";
/** ******************************************************************************
 * Copyright (C) 2018 Red Hat, Inc. and others.
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Public License v. 2.0 which is available at
 * http://www.eclipse.org/legal/epl-2.0.
 *
 * This Source Code may also be made available under the following Secondary
 * Licenses when the conditions for such availability set forth in the Eclipse
 * Public License v. 2.0 are satisfied: GNU General Public License, version 2
 * with the GNU Classpath Exception which is available at
 * https://www.gnu.org/software/classpath/license.html.
 *
 * SPDX-License-Identifier: EPL-2.0 OR GPL-2.0 WITH Classpath-exception-2.0
 ********************************************************************************/
Object.defineProperty(exports, "__esModule", { value: true });
exports.handleError = exports.isErrnoException = exports.notEmpty = exports.containsExtraFileMethod = exports.FileSystemError = exports.markAsFileSystemProviderError = exports.createFileSystemProviderError = exports.FileOperationError = exports.FileSystemProviderError = exports.FileSystemProviderErrorCode = exports.FileAccess = exports.IFileService = exports.IShadowFileProvider = exports.IDiskFileProvider = exports.FileStat = exports.FileType = void 0;
const tslib_1 = require("tslib");
// Some code copied and modified from https://github.com/eclipse-theia/theia/tree/v1.14.0/packages/filesystem/src/common/filesystem.ts
const ide_core_common_1 = require("@opensumi/ide-core-common");
var file_1 = require("@opensumi/ide-core-common/lib/types/file");
Object.defineProperty(exports, "FileType", { enumerable: true, get: function () { return file_1.FileType; } });
Object.defineProperty(exports, "FileStat", { enumerable: true, get: function () { return file_1.FileStat; } });
tslib_1.__exportStar(require("@opensumi/ide-core-common/lib/types/file-watch"), exports);
exports.IDiskFileProvider = Symbol('IDiskFileProvider');
exports.IShadowFileProvider = Symbol('IShadowFileProvider');
exports.IFileService = Symbol('IFileService');
var FileAccess;
(function (FileAccess) {
    let Constants;
    (function (Constants) {
        /**
         * Flag indicating that the file is visible to the calling process.
         * This is useful for determining if a file exists, but says nothing about rwx permissions. Default if no mode is specified.
         */
        Constants.F_OK = 0;
        /**
         * Flag indicating that the file can be read by the calling process.
         */
        Constants.R_OK = 4;
        /**
         * Flag indicating that the file can be written by the calling process.
         */
        Constants.W_OK = 2;
        /**
         * Flag indicating that the file can be executed by the calling process.
         * This has no effect on Windows (will behave like `FileAccess.F_OK`).
         */
        Constants.X_OK = 1;
    })(Constants = FileAccess.Constants || (FileAccess.Constants = {}));
})(FileAccess = exports.FileAccess || (exports.FileAccess = {}));
var FileSystemProviderErrorCode;
(function (FileSystemProviderErrorCode) {
    FileSystemProviderErrorCode["FileExists"] = "EntryExists";
    FileSystemProviderErrorCode["FileNotFound"] = "EntryNotFound";
    FileSystemProviderErrorCode["FileNotADirectory"] = "EntryNotADirectory";
    FileSystemProviderErrorCode["FileIsADirectory"] = "EntryIsADirectory";
    FileSystemProviderErrorCode["FileIsOutOfSync"] = "FileIsOutOfSync";
    FileSystemProviderErrorCode["FileExceedsMemoryLimit"] = "EntryExceedsMemoryLimit";
    FileSystemProviderErrorCode["FileTooLarge"] = "EntryTooLarge";
    FileSystemProviderErrorCode["FileWriteLocked"] = "EntryWriteLocked";
    FileSystemProviderErrorCode["NoPermissions"] = "NoPermissions";
    FileSystemProviderErrorCode["Unavailable"] = "Unavailable";
    FileSystemProviderErrorCode["Unknown"] = "Unknown";
})(FileSystemProviderErrorCode = exports.FileSystemProviderErrorCode || (exports.FileSystemProviderErrorCode = {}));
class FileSystemProviderError extends Error {
    static declare(code, factory) {
        return Object.assign((...args) => createFileSystemProviderError(factory(...args), code), {
            is: (error) => { var _a; return (_a = error.stack) === null || _a === void 0 ? void 0 : _a.startsWith(code); },
        });
    }
    constructor(message, code) {
        super(message);
        this.code = code;
    }
    is(error) {
        return this.name === error.name;
    }
}
exports.FileSystemProviderError = FileSystemProviderError;
class FileOperationError extends Error {
    constructor(message, fileOperationResult, options) {
        super(message);
        this.fileOperationResult = fileOperationResult;
        this.options = options;
    }
    static isFileOperationError(obj) {
        return obj instanceof Error && !(0, ide_core_common_1.isUndefinedOrNull)(obj.fileOperationResult);
    }
}
exports.FileOperationError = FileOperationError;
function createFileSystemProviderError(error, code) {
    const providerError = new FileSystemProviderError(error.toString(), code);
    markAsFileSystemProviderError(providerError, code);
    return providerError;
}
exports.createFileSystemProviderError = createFileSystemProviderError;
function markAsFileSystemProviderError(error, code) {
    error.name = code ? `${code} (FileSystemError)` : 'FileSystemError';
    return error;
}
exports.markAsFileSystemProviderError = markAsFileSystemProviderError;
var FileSystemError;
(function (FileSystemError) {
    FileSystemError.FileNotFound = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileNotFound, (uri, prefix) => `${prefix ? prefix + ' ' : ''} '${uri}' is not found.`);
    FileSystemError.FileExists = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileExists, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' already exists.`);
    FileSystemError.FileNotADirectory = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileNotADirectory, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is not a directory.`);
    FileSystemError.FileIsADirectory = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileIsADirectory, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is a directory.`);
    FileSystemError.FileIsOutOfSync = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileIsOutOfSync, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is out of sync.`);
    FileSystemError.FileExceedsMemoryLimit = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileExceedsMemoryLimit, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is exceeds memory limit.`);
    FileSystemError.FileTooLarge = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileTooLarge, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is too large.`);
    FileSystemError.FileWriteLocked = FileSystemProviderError.declare(FileSystemProviderErrorCode.FileWriteLocked, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is locked.`);
    FileSystemError.FileIsNoPermissions = FileSystemProviderError.declare(FileSystemProviderErrorCode.NoPermissions, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is no permissions.`);
    FileSystemError.Unavailable = FileSystemProviderError.declare(FileSystemProviderErrorCode.Unavailable, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is unavailable.`);
    FileSystemError.Unknown = FileSystemProviderError.declare(FileSystemProviderErrorCode.Unknown, (uri, prefix) => `${prefix ? prefix + ' ' : ''}'${uri}' is unkonw.`);
})(FileSystemError = exports.FileSystemError || (exports.FileSystemError = {}));
/**
 * 判断一个对象是否包含某个方法
 * @param obj object
 * @param prop string
 */
function containsExtraFileMethod(obj, prop) {
    return (0, ide_core_common_1.hasProperty)(obj, prop) && (0, ide_core_common_1.isFunction)(obj[prop]);
}
exports.containsExtraFileMethod = containsExtraFileMethod;
function notEmpty(value) {
    return value !== undefined;
}
exports.notEmpty = notEmpty;
function isErrnoException(error) {
    return error.code !== undefined && error.errno !== undefined;
}
exports.isErrnoException = isErrnoException;
function handleError(error) {
    var _a, _b, _c, _d, _e;
    if (isErrnoException(error)) {
        switch (error.code) {
            case 'EEXIST':
                throw FileSystemError.FileExists(ide_core_common_1.Uri.file((_a = error.path) !== null && _a !== void 0 ? _a : ''));
            case 'EPERM':
            case 'EACCESS':
                throw FileSystemError.FileIsNoPermissions(ide_core_common_1.Uri.file((_b = error.path) !== null && _b !== void 0 ? _b : ''));
            case 'ENOENT':
                throw FileSystemError.FileNotFound(ide_core_common_1.Uri.file((_c = error.path) !== null && _c !== void 0 ? _c : ''));
            case 'ENOTDIR':
                throw FileSystemError.FileNotADirectory(ide_core_common_1.Uri.file((_d = error.path) !== null && _d !== void 0 ? _d : ''));
            case 'EISDIR':
                throw FileSystemError.FileIsADirectory(ide_core_common_1.Uri.file((_e = error.path) !== null && _e !== void 0 ? _e : ''));
        }
    }
    throw error;
}
exports.handleError = handleError;
//# sourceMappingURL=files.js.map