import { Injector } from '@opensumi/di';
import { DisposableCollection, Emitter, Event, IDisposable, ParsedPattern, URI, Uri, getEncodingInfo } from '@opensumi/ide-core-node';
import { DidFilesChangedParams, FileChangeEvent, FileCopyOptions, FileCreateOptions, FileDeleteOptions, FileMoveOptions, FileSetContentOptions, FileStat, FileSystemProvider, IFileService, TextDocumentContentChangeEvent } from '../common';
import { FileSystemManage } from './file-system-manage';
export declare abstract class FileSystemNodeOptions {
    static DEFAULT: FileSystemNodeOptions;
    abstract encoding: string;
    abstract recursive: boolean;
    abstract overwrite: boolean;
    abstract moveToTrash: boolean;
}
export declare class FileService implements IFileService {
    protected readonly options: FileSystemNodeOptions;
    protected watcherId: number;
    protected readonly watcherDisposerMap: Map<number, IDisposable>;
    protected readonly watcherWithSchemaMap: Map<string, number[]>;
    protected readonly onFileChangedEmitter: Emitter<DidFilesChangedParams>;
    protected readonly fileSystemManage: FileSystemManage;
    readonly onFilesChanged: Event<DidFilesChangedParams>;
    protected toDisposable: DisposableCollection;
    protected filesExcludes: string[];
    protected filesExcludesMatcherList: ParsedPattern[];
    protected workspaceRoots: string[];
    private readonly logger;
    injector: Injector;
    constructor(options: FileSystemNodeOptions);
    registerProvider(scheme: string, provider: FileSystemProvider): IDisposable;
    watchFileChanges(uri: string, options?: {
        excludes: string[];
    }): Promise<number>;
    unwatchFileChanges(watcherId: number): Promise<void>;
    setWatchFileExcludes(excludes: string[]): void;
    getWatchFileExcludes(): string[];
    setFilesExcludes(excludes: string[], roots?: string[]): void;
    getFilesExcludes(): string[];
    setWorkspaceRoots(roots: string[]): void;
    getFileStat(uri: string): Promise<FileStat | undefined>;
    exists(uri: string): Promise<boolean>;
    resolveContent(uri: string, options?: FileSetContentOptions): Promise<{
        stat: FileStat;
        content: string;
    }>;
    setContent(file: FileStat, content: string, options?: FileSetContentOptions): Promise<FileStat>;
    updateContent(file: FileStat, contentChanges: TextDocumentContentChangeEvent[], options?: FileSetContentOptions): Promise<FileStat>;
    move(sourceUri: string, targetUri: string, options?: FileMoveOptions): Promise<FileStat>;
    copy(sourceUri: string, targetUri: string, options?: FileCopyOptions): Promise<FileStat>;
    createFile(uri: string, options?: FileCreateOptions): Promise<FileStat>;
    createFolder(uri: string): Promise<FileStat>;
    /**
     * @param {string} uri
     * @param {FileDeleteOptions} [options] Only support scheme `file`
     * @returns {Promise<void>}
     * @memberof FileService
     */
    delete(uri: string, options?: FileDeleteOptions): Promise<void>;
    access(uri: string, mode?: number): Promise<boolean>;
    /**
     * Only support scheme `file`
     * @param {string} uri
     * @returns {Promise<string>}
     * @memberof FileService
     */
    getEncoding(uri: string): Promise<string>;
    getEncodingInfo: typeof getEncodingInfo;
    getCurrentUserHome(): Promise<FileStat | undefined>;
    /**
     *
     * Only support scheme `file`
     */
    getFsPath(uri: string): Promise<string | undefined>;
    getFileType(uri: string): Promise<string | undefined>;
    getUri(uri: string | Uri): URI;
    /**
     * Current policy: sends * all * Provider onDidChangeFile events to * all * clients and listeners
     */
    fireFilesChange(e: FileChangeEvent): false | undefined;
    dispose(): void;
    private updateExcludeMatcher;
    private isExclude;
    private filterStat;
    private filterStatChildren;
    private getNodeBuffer;
    private getErrorProvideNotSupport;
    private initProvider;
    private getProvider;
    protected applyContentChanges(content: string, contentChanges: TextDocumentContentChangeEvent[]): string;
    protected isInSync(file: FileStat, stat: FileStat): Promise<boolean>;
    protected checkInSync(file: FileStat, stat: FileStat): boolean;
    protected createOutOfSyncError(file: FileStat, stat: FileStat): Error;
    /**
     * Filters hidden and system partitions.
     */
    protected filterMountpointPath(path: string): boolean;
    protected doGetEncoding(option?: {
        encoding?: string;
    }): Promise<string>;
    protected doGetOverwrite(option?: {
        overwrite?: boolean;
    }): Promise<boolean | undefined>;
    protected doGetRecursive(option?: {
        recursive?: boolean;
    }): Promise<boolean>;
    protected doGetMoveToTrash(option?: {
        moveToTrash?: boolean;
    }): Promise<boolean>;
    protected doGetContent(option?: {
        content?: string;
    }): Promise<string>;
}
export declare function getSafeFileservice(injector: Injector): IFileService | FileService | undefined;
//# sourceMappingURL=file-service.d.ts.map